@@ -1,10 +1,10 @@
 use swc_common::{ast_node, Span};
 
-use crate::{CustomIdent, DeclarationBlockItem};
+use crate::{CustomIdent, SimpleBlock};
 
 #[ast_node("CounterStyleRule")]
 pub struct CounterStyleRule {
     pub span: Span,
     pub name: CustomIdent,
-    pub block: Vec<DeclarationBlockItem>,
+    pub block: SimpleBlock,
 }
