@@ -2,11 +2,10 @@
 #![allow(clippy::large_enum_variant)]
 
 //! AST definitions for CSS.
-pub use self::{at_rule::*, base::*, selector::*, style_rule::*, token::*, value::*};
+pub use self::{at_rule::*, base::*, selector::*, token::*, value::*};
 
 mod at_rule;
 mod base;
 mod selector;
-mod style_rule;
 mod token;
 mod value;
